/// <reference types="react" />
/**
 *  Created by Christopher VUONG
 *  Extend from XmlEditor
 */
import * as React from 'react';
import { UserModel } from './models/UserModel';
import AceSession from './models/AceSession';
import * as ace from 'brace';
/**
 * Ace editor mode
 */
import 'brace/mode/csharp';
import 'brace/mode/dockerfile';
import 'brace/mode/groovy';
import 'brace/mode/html';
import 'brace/mode/java';
import 'brace/mode/javascript';
import 'brace/mode/json';
import 'brace/mode/typescript';
import 'brace/mode/tsx';
import 'brace/mode/xml';
/**
 * Ace editor theme
 */
import 'brace/theme/ambiance';
import 'brace/theme/chaos';
import 'brace/theme/chrome';
import 'brace/theme/clouds';
import 'brace/theme/clouds_midnight';
import 'brace/theme/cobalt';
import 'brace/theme/crimson_editor';
import 'brace/theme/dawn';
import 'brace/theme/dracula';
import 'brace/theme/dreamweaver';
import 'brace/theme/eclipse';
import 'brace/theme/github';
import 'brace/theme/gob';
import 'brace/theme/gruvbox';
import 'brace/theme/idle_fingers';
import 'brace/theme/iplastic';
import 'brace/theme/katzenmilch';
import 'brace/theme/kr_theme';
import 'brace/theme/kuroir';
import 'brace/theme/merbivore';
import 'brace/theme/merbivore_soft';
import 'brace/theme/mono_industrial';
import 'brace/theme/monokai';
import 'brace/theme/pastel_on_dark';
import 'brace/theme/solarized_dark';
import 'brace/theme/solarized_light';
import 'brace/theme/sqlserver';
import 'brace/theme/terminal';
import 'brace/theme/textmate';
import 'brace/theme/tomorrow';
import 'brace/theme/tomorrow_night';
import 'brace/theme/tomorrow_night_blue';
import 'brace/theme/tomorrow_night_bright';
import 'brace/theme/tomorrow_night_eighties';
import 'brace/theme/twilight';
import 'brace/theme/vibrant_ink';
import 'brace/theme/xcode';
declare module CodeEditor {
    /**
     * CodeEditor properties
     */
    interface Props extends React.Props<CodeEditor> {
        /** Editor height. */
        height?: number | string;
        /** Initial content of the editor. */
        value: string;
        /** Editor language mode. Default value is <strong>javascript</strong>. */
        mode: string;
        /** If true don't allow user to edit content. */
        readonly?: boolean;
        /** Editor visual settings. */
        displaySettings?: Settings;
        /** Initial load time of editor. If the new loadTime is at a later date, the editor will be updated. */
        loadTime: number;
        /** @deprecated loadTime property will be used instead in next release. */
        resetTick?: number;
        /** Set ace session. */
        aceSession?: AceSession;
        /** Unique editor id. */
        docId: string;
        /** Preferred user's displaySettings. Set on the user profile, you can provide the userJson object but shouldn't modify this value. */
        userJson?: UserModel.JsonContent;
        /** Save ace session after each update. */
        saveSession?: (session: AceSession) => void;
        /**
         * Force save with keyboard shortcuts <strong>Ctrl + s</strong> or <strong>Cmd + s</strong>.
         */
        saveContent?: (session: AceSession) => void;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<CodeEditor>;
    }
    interface Settings {
        theme?: string;
        fontSize?: string;
        fontFamily?: string;
        showInvisibles?: boolean;
        showGutter?: boolean;
        showIndent?: boolean;
        wrap?: boolean;
        highlight?: boolean;
        marker?: Marker;
    }
    interface Marker {
        row: number;
        column: number;
    }
}
/**
 * Editor used outside a form. Principally used to display readable only exemple,
 * but can also keep current editor state if needed.
 */
declare class CodeEditor extends React.Component<CodeEditor.Props, any> {
    private _markerId;
    private _firstChangeTime;
    private _editorPanel;
    private _editor;
    constructor(props: CodeEditor.Props);
    render(): JSX.Element;
    componentWillMount(): void;
    componentDidMount(): void;
    componentWillUnmount(): void;
    shouldComponentUpdate(nextProps: CodeEditor.Props): boolean;
    componentDidUpdate(): void;
    focus(session: AceSession): void;
    private resizeEditor;
    private setEditorSession(editor, props);
    getAceSession: (editor: ace.Editor) => AceSession;
    extractAceSession: (editor: ace.Editor) => AceSession;
    private static restoreSession(editor, data);
    private setEditorOptions;
    private isSessionSavable;
    private setKeyboardShortcuts;
}
export default CodeEditor;
