import { ScopeValue, PermissionDef, ScopesTree } from './models/Scopes';
/**
 * User got permission.
 * e.g: reports=view
 */
export declare function hasPermission(appInstance: string, scopesTree: ScopesTree, permission: string, global?: boolean): boolean;
/**
 * User got all permissions.
 * e.g: ['reports=view', 'reports=read']
 */
export declare function hasAnyPermission(appInstance: string, scopesTree: ScopesTree, permissions: string[] | PermissionDef[], global?: boolean): boolean;
/**
 * Get item values from permission.
 * e.g: reports=read('Test'), will return ['Test'].
 */
export declare function getScopeValues(appInstance: string, scopesTree: ScopesTree, feature: string, action: string): ScopeValue | string[];
/**
 * User has access to feature id.
 * e.g: reports=read, here 'reports' is the feature id.
 */
export declare function hasAccessToFeature(appInstance: string, scopesTree: ScopesTree, feature: string, global?: boolean): boolean;
/**
 * Action has filter on it.
 */
export declare function hasFilterOn(appInstance: string, scopesTree: ScopesTree, feature: string, viewFilter: string, filterKey: string): boolean;
/**
 * True if only one requiredActions is contain within the authorizedActions.
 */
export declare function canPerformAnyAction(requiredActions: string[], authorizedActions: string[]): boolean;
