/// <reference types="react" />
/// <reference types="jstree" />
import * as React from 'react';
import { TreeNodeModel, OrgModel, KeyValDef } from './models/tree';
declare module Tree {
    interface Props extends React.Props<Tree> {
        /** Any unique DOM ID. */
        id: string;
        /** Data to render as a tree. See below for the required data model behind the TreeNodeModel interface */
        data: TreeNodeModel;
        /**
         * Function to create a node.
         * Data update logic needs to be implemented based on the provided parameters.
         * See below for the required data model behind the KeyValDef interface.
         */
        createNode?: (parentId: string, elementName: string, description: string, propertiesMap?: KeyValDef) => void;
        /** Manage node edition. */
        editNode?: (id: string, elementName: string, description: string, propertiesMap?: KeyValDef, parentNodeId?: string) => void;
        /** Manage node deletion. */
        deleteNode?: (id: string, elementName: string, parentNodeId?: string) => void;
        /** Manage errors display. */
        displayEmptyValsError?: (emptyVals: string[]) => void;
        /** Manage node selection. */
        selectCallback?: (node: TreeNodeModel) => void;
        /** Set default selected node. */
        defaultSelectedNodeId?: string;
        /** Locale to be used. */
        locale: string;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<Tree>;
    }
    interface State {
        treeInstance?: JSTree;
        selectedNode?: TreeNodeModel;
        formOpened?: string;
        editedNode?: OrgModel;
        maxTreeHeight?: number;
        wordings?: {
            [key: string]: string;
        };
    }
}
/**
 * Organize custom tree allowing you to manage nodes and attached data to it.
 * Attached data can be either texts or files.
 */
declare class Tree extends React.Component<Tree.Props, Tree.State> {
    private _tree;
    constructor(props: Tree.Props);
    render(): JSX.Element;
    componentDidMount(): void;
    componentDidUpdate(prevProps: Tree.Props, prevState: Tree.State): void;
    componentWillReceiveProps(nextProps: Tree.Props): void;
    componentWillUnmount(): void;
    private downloadFile;
    private expandAll;
    private collapseAll;
    private openCreateForm;
    private createNode;
    private openEditForm;
    private editNode;
    private deleteNode;
    private clearForm;
    private handleElementNameChange;
    private handleDescriptionChange;
    private handlePropertiesChange;
    private setUpTree;
    private getDecodedNode;
}
export default Tree;
